@@ -8,11 +8,13 @@ import json
 from pathlib import Path
 from .tools import abort
 
+
 @cli.group(cls=AliasedGroup)
 @pass_config
 def docker(config):
     pass
 
+
 @docker.command()
 @pass_config
 @click.pass_context
@@ -33,32 +35,36 @@ def dev(ctx, config, build, kill):
     return lib_dev(ctx, config, build, kill)
 
 
-@docker.command(name='ps')
+@docker.command(name="ps")
 @pass_config
 def ps(config):
     if config.use_docker:
         from .lib_control_with_docker import ps as lib_ps
     return lib_ps()
 
-@docker.command(name='exec')
-@click.argument('machine', required=True)
-@click.argument('args', nargs=-1)
+
+@docker.command(name="exec")
+@click.argument("machine", required=True)
+@click.argument("args", nargs=-1)
 @pass_config
 def execute(config, machine, args):
     if config.use_docker:
         from .lib_control_with_docker import execute as lib_execute
     lib_execute(machine, args)
 
-@docker.command(name='kill')
-@click.argument('machines', nargs=-1)
-@click.option('-b', '--brutal', is_flag=True, help='dont wait')
+
+@docker.command(name="kill")
+@click.argument("machines", nargs=-1)
+@click.option("-b", "--brutal", is_flag=True, help="dont wait")
 @pass_config
 @click.pass_context
 def do_kill(ctx, config, machines, brutal=False):
     if config.use_docker:
         from .lib_control_with_docker import do_kill as lib_do_kill
+
         lib_do_kill(ctx, config, machines, brutal=False)
 
+
 @docker.command()
 @pass_config
 @click.pass_context
@@ -67,13 +73,18 @@ def force_kill(ctx, config, machine):
         from .lib_control_with_docker import force_kill as lib_force_kill
     lib_force_kill(ctx, config, machine)
 
+
 @docker.command()
 @pass_config
 def wait_for_container_postgres(config):
     if config.use_docker:
-        from .lib_control_with_docker import wait_for_container_postgres as lib_wait_for_container_postgres
+        from .lib_control_with_docker import (
+            wait_for_container_postgres as lib_wait_for_container_postgres,
+        )
+
         lib_wait_for_container_postgres(config)
 
+
 @docker.command()
 @pass_config
 def wait_for_port(config, host, port):
@@ -81,8 +92,9 @@ def wait_for_port(config, host, port):
         from .lib_control_with_docker import wait_for_port as lib_wait_for_port
     lib_wait_for_port(host, port)
 
+
 @docker.command()
-@click.argument('machines', nargs=-1)
+@click.argument("machines", nargs=-1)
 @pass_config
 @click.pass_context
 def recreate(ctx, config, machines):
@@ -90,9 +102,10 @@ def recreate(ctx, config, machines):
         from .lib_control_with_docker import recreate as lib_recreate
     lib_recreate(ctx, config, machines)
 
+
 @docker.command()
-@click.argument('machines', nargs=-1)
-@click.option('-d', '--daemon', is_flag=True)
+@click.argument("machines", nargs=-1)
+@click.option("-d", "--daemon", is_flag=True)
 @pass_config
 @click.pass_context
 def up(ctx, config, machines, daemon):
@@ -101,13 +114,16 @@ def up(ctx, config, machines, daemon):
     else:
         from .lib_control_native import up as lib_up
     lib_up(ctx, config, machines, daemon, remove_orphans=True)
-    execute_script(config, config.files['after_up_script'], 'Possible after up script here:')
+    execute_script(
+        config, config.files["after_up_script"], "Possible after up script here:"
+    )
+
 
 @docker.command()
-@click.argument('machines', nargs=-1)
-@click.option('-v', '--volumes', is_flag=True)
-@click.option('--remove-orphans', is_flag=True)
-@click.option('--postgres-volume', is_flag=True)
+@click.argument("machines", nargs=-1)
+@click.option("-v", "--volumes", is_flag=True)
+@click.option("--remove-orphans", is_flag=True)
+@click.option("--postgres-volume", is_flag=True)
 @pass_config
 @click.pass_context
 def down(ctx, config, machines, volumes, remove_orphans, postgres_volume):
@@ -121,23 +137,25 @@ def down(ctx, config, machines, volumes, remove_orphans, postgres_volume):
                 abort("Please use force when call with postgres volume")
         lib_down(ctx, config, machines, volumes=False, remove_orphans=False)
         try:
-            Commands.invoke(ctx, 'remove_postgres_volume')
+            Commands.invoke(ctx, "remove_postgres_volume")
         except NotZFS:
             pass
 
     lib_down(ctx, config, machines, volumes, remove_orphans)
 
-@docker.command()
-@click.argument('machines', nargs=-1)
-@pass_config
-@click.pass_context
-def stop(ctx, config,  machines):
-    if config.use_docker:
-        from .lib_control_with_docker import stop as lib_stop
-    lib_stop(ctx, config,  machines)
 
 @docker.command()
-@click.argument('machines', nargs=-1)
+@click.argument("machines", nargs=-1)
+@pass_config
+@click.pass_context
+def stop(ctx, config, machines):
+    if config.use_docker:
+        from .lib_control_with_docker import stop as lib_stop
+    lib_stop(ctx, config, machines)
+
+
+@docker.command()
+@click.argument("machines", nargs=-1)
 @pass_config
 @click.pass_context
 def rebuild(ctx, config, machines):
@@ -145,8 +163,9 @@ def rebuild(ctx, config, machines):
         from .lib_control_with_docker import rebuild as lib_rebuild
     lib_rebuild(ctx, config, machines)
 
+
 @docker.command()
-@click.argument('machines', nargs=-1)
+@click.argument("machines", nargs=-1)
 @pass_config
 @click.pass_context
 def restart(ctx, config, machines):
@@ -154,8 +173,9 @@ def restart(ctx, config, machines):
         from .lib_control_with_docker import restart as lib_restart
     lib_restart(ctx, config, machines)
 
+
 @docker.command()
-@click.argument('machines', nargs=-1)
+@click.argument("machines", nargs=-1)
 @pass_config
 @click.pass_context
 def rm(ctx, config, machines):
@@ -163,8 +183,9 @@ def rm(ctx, config, machines):
         from .lib_control_with_docker import rm as lib_rm
     lib_rm(ctx, config, machines)
 
+
 @docker.command()
-@click.argument('machine', required=True)
+@click.argument("machine", required=True)
 @pass_config
 @click.pass_context
 def attach(ctx, config, machine):
@@ -172,25 +193,27 @@ def attach(ctx, config, machine):
         from .lib_control_with_docker import attach as lib_attach
     lib_attach(ctx, config, machine)
 
+
 @docker.command()
-@click.argument('machines', nargs=-1)
-@click.option('--no-cache', is_flag=True)
-@click.option('--pull', is_flag=True)
-@click.option('--push', is_flag=True)
-@click.option('-p', '--plain', is_flag=True)
+@click.argument("machines", nargs=-1)
+@click.option("--no-cache", is_flag=True)
+@click.option("--pull", is_flag=True)
+@click.option("--push", is_flag=True)
+@click.option("-p", "--plain", is_flag=True)
 @pass_config
 @click.pass_context
 def build(ctx, config, machines, pull, no_cache, push, plain):
     if plain:
-        os.environ['BUILDKIT_PROGRESS'] = 'plain'
+        os.environ["BUILDKIT_PROGRESS"] = "plain"
     if config.use_docker:
         from .lib_control_with_docker import build as lib_build
     lib_build(ctx, config, machines, pull, no_cache, push)
 
+
 @docker.command()
-@click.argument('machine', required=True)
-@click.option('-c', '--command', required=False, help="Like /odoolib/debug.py")
-@click.option('-p', '--ports', is_flag=True, help='With Port 33284')
+@click.argument("machine", required=True)
+@click.option("-c", "--command", required=False, help="Like /odoolib/debug.py")
+@click.option("-p", "--ports", is_flag=True, help="With Port 33284")
 @pass_config
 @click.pass_context
 def debug(ctx, config, machine, ports, command):
@@ -198,9 +221,10 @@ def debug(ctx, config, machine, ports, command):
         from .lib_control_with_docker import debug as lib_debug
     lib_debug(ctx, config, machine, ports, cmd=command)
 
+
 @cli.command()
-@click.argument('machine', required=True)
-@click.argument('args', nargs=-1)
+@click.argument("machine", required=True)
+@click.argument("args", nargs=-1)
 @pass_config
 @click.pass_context
 def run(ctx, config, machine, args, **kwparams):
@@ -208,9 +232,10 @@ def run(ctx, config, machine, args, **kwparams):
         from .lib_control_with_docker import run as lib_run
     lib_run(ctx, config, machine, args, **kwparams)
 
+
 @cli.command()
-@click.argument('machine', required=True)
-@click.argument('args', nargs=-1)
+@click.argument("machine", required=True)
+@click.argument("args", nargs=-1)
 @pass_config
 @click.pass_context
 def runbash(ctx, config, machine, args, **kwparams):
@@ -218,20 +243,26 @@ def runbash(ctx, config, machine, args, **kwparams):
         from .lib_control_with_docker import runbash as lib_runbash
     lib_runbash(ctx, config, machine, args, **kwparams)
 
-@cli.command(name='logs')
-@click.argument('machines', nargs=-1)
-@click.option('-n', '--lines', required=False, type=int, default=200)
-@click.option('-f', '--follow', is_flag=True)
+
+@cli.command(name="logs")
+@click.argument("machines", nargs=-1)
+@click.option("-n", "--lines", required=False, type=int, default=200)
+@click.option("-f", "--follow", is_flag=True)
 @pass_config
 def logall(config, machines, follow, lines):
     if config.use_docker:
         from .lib_control_with_docker import logall as lib_logall
     lib_logall(machines, follow, lines)
 
+
 @docker.command()
-@click.argument('command', nargs=-1)
-@click.option("-q", "--queuejobs", is_flag=True, help=(
-    "Dont delay queuejobs / execute queuejob code"))
+@click.argument("command", nargs=-1)
+@click.option(
+    "-q",
+    "--queuejobs",
+    is_flag=True,
+    help=("Dont delay queuejobs / execute queuejob code"),
+)
 @pass_config
 def shell(config, command, queuejobs):
     command = "\n".join(command)
@@ -239,6 +270,7 @@ def shell(config, command, queuejobs):
         from .lib_control_with_docker import shell as lib_shell
     lib_shell(command, queuejobs)
 
+
 # problem with stdin: debug then display missing
 # @docker.command()
 # @click.argument("id", required=True)
@@ -253,16 +285,22 @@ def shell(config, command, queuejobs):
 #     )
 #     lib_shell(command, queuejobs)
 
+
 @docker.command()
-@click.option('-f', '--filter')
+@click.option("-f", "--filter")
 @pass_config
 def show_volumes(config, filter):
     import yaml
     from tabulate import tabulate
     from .lib_control_with_docker import _get_volume_size
-    volumes = subprocess.check_output(["docker", "volume", "ls"]).decode('utf-8').split("\n")[1:]
+
+    volumes = (
+        subprocess.check_output(["docker", "volume", "ls"])
+        .decode("utf-8")
+        .split("\n")[1:]
+    )
     volumes = [x.split(" ")[-1] for x in volumes]
-    volumes = [[x] for x in volumes if '_' in x]  # named volumes
+    volumes = [[x] for x in volumes if "_" in x]  # named volumes
     volumes = [x for x in volumes if config.project_name in x[0]]
     if filter:
         volumes = [x for x in volumes if filter in x]
@@ -272,14 +310,15 @@ def show_volumes(config, filter):
     click.echo(tabulate(volumes, ["Volume", "Size"]))
 
     click.secho("\ndocker-compose file:", bold=True)
-    compose = yaml.safe_load(config.files['docker_compose'].read_text())
-    for volume in compose['volumes']:
+    compose = yaml.safe_load(config.files["docker_compose"].read_text())
+    for volume in compose["volumes"]:
         click.secho(f"docker-compose volume: {volume}")
 
+
 @docker.command()
-@click.option('-a', '--show-all', is_flag=True)
-@click.option('-f', '--filter')
-@click.option('-B', '--no-backup', is_flag=True)
+@click.option("-a", "--show-all", is_flag=True)
+@click.option("-f", "--filter")
+@click.option("-B", "--no-backup", is_flag=True)
 @pass_config
 @click.pass_context
 def transfer_volume_content(context, config, show_all, filter, no_backup):
@@ -288,9 +327,14 @@ def transfer_volume_content(context, config, show_all, filter, no_backup):
     from pathlib import Path
     from .lib_control_with_docker import _get_volume_size
     from .lib_control_with_docker import _get_volume_hostpath
-    volumes = subprocess.check_output(["docker", "volume", "ls"]).decode('utf-8').split("\n")[1:]
+
+    volumes = (
+        subprocess.check_output(["docker", "volume", "ls"])
+        .decode("utf-8")
+        .split("\n")[1:]
+    )
     volumes = [x.split(" ")[-1] for x in volumes]
-    volumes = [x for x in volumes if '_' in x]  # named volumes
+    volumes = [x for x in volumes if "_" in x]  # named volumes
 
     if filter:
         volumes = [x for x in volumes if filter in x]
@@ -315,68 +359,73 @@ def transfer_volume_content(context, config, show_all, filter, no_backup):
 
     questions = [
         inquirer.List(
-            'volume',
+            "volume",
             message="Select source:".format(config.customs, config.dbname),
             choices=volumes1,
         ),
     ]
     answers = inquirer.prompt(questions)
-    if not answers or not answers['volume']:
+    if not answers or not answers["volume"]:
         return
 
-    source = answers['volume']
+    source = answers["volume"]
     volumes2.pop(volumes2.index(source))
     questions = [
         inquirer.List(
-            'volume',
+            "volume",
             message="Select Destination:".format(config.customs, config.dbname),
             choices=volumes2,
         ),
     ]
     answers = inquirer.prompt(questions)
-    if not answers or not answers['volume']:
+    if not answers or not answers["volume"]:
         return
     source = _get_volume_hostpath(source.split(" [")[0])
-    dest = _get_volume_hostpath(answers['volume'].split(" [")[0])
+    dest = _get_volume_hostpath(answers["volume"].split(" [")[0])
 
     tasks = []
-    tasks.append(f'rsync -ar --delete-after {source.name} to {dest.name}')
+    tasks.append(f"rsync -ar --delete-after {source.name} to {dest.name}")
     for i, task in enumerate(tasks):
         click.secho(f"{i}. {task}")
-    answer = inquirer.prompt([inquirer.Confirm('continue', message=("Continue?"))])
-    if not answer['continue']:
+    answer = inquirer.prompt([inquirer.Confirm("continue", message=("Continue?"))])
+    if not answer["continue"]:
         return
-    Commands.invoke(context, 'down')
+    Commands.invoke(context, "down")
 
     if not no_backup:
         click.secho("Rsyncing files to /tmp as backup...")
         backup_name = str(Path("/tmp/") / dest.name) + ".bak"
-        subprocess.check_call([
-            '/usr/bin/sudo',
-            'rsync',
-            '-ar',
-            str(dest / '_data') + '/',
-            backup_name + '/',
-        ])
+        subprocess.check_call(
+            [
+                "/usr/bin/sudo",
+                "rsync",
+                "-ar",
+                str(dest / "_data") + "/",
+                backup_name + "/",
+            ]
+        )
         click.secho(f"Made backup in {backup_name}")
 
     click.secho(f"Rsyncing files from old source to {dest}")
 
     command = [
-        'rsync',
-        '-arP',
-        '--delete-after',
-        str(source / '_data') + '/',
-        str(dest / '_data') + '/',
+        "rsync",
+        "-arP",
+        "--delete-after",
+        str(source / "_data") + "/",
+        str(dest / "_data") + "/",
     ]
-    subprocess.check_call([
-        '/usr/bin/sudo',
-    ] + command)
+    subprocess.check_call(
+        [
+            "/usr/bin/sudo",
+        ]
+        + command
+    )
 
 
 Commands.register(run)
 Commands.register(runbash)
-Commands.register(do_kill, 'kill')
+Commands.register(do_kill, "kill")
 Commands.register(up)
 Commands.register(wait_for_container_postgres)
 Commands.register(build)
@@ -384,6 +433,6 @@ Commands.register(rm)
 Commands.register(recreate)
 Commands.register(debug)
 Commands.register(restart)
-Commands.register(shell, 'odoo-shell')
+Commands.register(shell, "odoo-shell")
 Commands.register(down)
 Commands.register(stop)
